package com.os.ems.info.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.common.exception.ServiceException;
import com.os.common.utils.StringUtils;
import com.os.ems.info.mapper.SparePartsInventoryCheckMapper;
import com.os.ems.info.domain.SparePartsInventoryCheck;
import com.os.ems.info.service.ISparePartsInventoryCheckService;

/**
 * 备件盘点记录明细Service业务层处理
 * 
 * @author Yinq
 * @date 2025-06-05
 */
@Service
public class SparePartsInventoryCheckServiceImpl implements ISparePartsInventoryCheckService 
{
    @Autowired
    private SparePartsInventoryCheckMapper sparePartsInventoryCheckMapper;

    /**
     * 查询备件盘点记录明细
     * 
     * @param id 备件盘点记录明细主键
     * @return 备件盘点记录明细
     */
    @Override
    public SparePartsInventoryCheck selectSparePartsInventoryCheckById(Long id)
    {
        return sparePartsInventoryCheckMapper.selectSparePartsInventoryCheckById(id);
    }

    /**
     * 查询备件盘点记录明细列表
     * 
     * @param sparePartsInventoryCheck 备件盘点记录明细
     * @return 备件盘点记录明细
     */
    @Override
    public List<SparePartsInventoryCheck> selectSparePartsInventoryCheckList(SparePartsInventoryCheck sparePartsInventoryCheck)
    {
        return sparePartsInventoryCheckMapper.selectSparePartsInventoryCheckList(sparePartsInventoryCheck);
    }

    /**
     * 新增备件盘点记录明细
     * 
     * @param sparePartsInventoryCheck 备件盘点记录明细
     * @return 结果
     */
    @Override
    public int insertSparePartsInventoryCheck(SparePartsInventoryCheck sparePartsInventoryCheck)
    {
        return sparePartsInventoryCheckMapper.insertSparePartsInventoryCheck(sparePartsInventoryCheck);
    }

    /**
     * 修改备件盘点记录明细
     * 
     * @param sparePartsInventoryCheck 备件盘点记录明细
     * @return 结果
     */
    @Override
    public int updateSparePartsInventoryCheck(SparePartsInventoryCheck sparePartsInventoryCheck)
    {
        return sparePartsInventoryCheckMapper.updateSparePartsInventoryCheck(sparePartsInventoryCheck);
    }

    /**
     * 批量删除备件盘点记录明细
     * 
     * @param ids 需要删除的备件盘点记录明细主键
     * @return 结果
     */
    @Override
    public int deleteSparePartsInventoryCheckByIds(Long[] ids)
    {
        return sparePartsInventoryCheckMapper.deleteSparePartsInventoryCheckByIds(ids);
    }

    /**
     * 删除备件盘点记录明细信息
     * 
     * @param id 备件盘点记录明细主键
     * @return 结果
     */
    @Override
    public int deleteSparePartsInventoryCheckById(Long id)
    {
        return sparePartsInventoryCheckMapper.deleteSparePartsInventoryCheckById(id);
    }

    /**
     * 导入备件盘点记录明细数据
     *
     * @param recordList 记录数据列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    @Override
    public String importSparePartsInventoryCheck(List<SparePartsInventoryCheck> recordList, Boolean isUpdateSupport, String operName)
    {
        if (StringUtils.isNull(recordList) || recordList.size() == 0)
        {
            throw new ServiceException("导入数据不能为空！");
        }
        int successNum = 0;
        int failureNum = 0;
        StringBuilder successMsg = new StringBuilder();
        StringBuilder failureMsg = new StringBuilder();
        for (SparePartsInventoryCheck record : recordList)
        {
            try
            {
                // 设置操作人
                record.setCreateBy(operName);
                
                // 验证是否存在这个记录
                SparePartsInventoryCheck existRecord = null;
                if (StringUtils.isNotEmpty(record.getCheckDate()) && StringUtils.isNotEmpty(record.getCheckName()))
                {
                    SparePartsInventoryCheck queryRecord = new SparePartsInventoryCheck();
                    queryRecord.setCheckDate(record.getCheckDate());
                    queryRecord.setCheckName(record.getCheckName());
                    List<SparePartsInventoryCheck> existRecords = sparePartsInventoryCheckMapper.selectSparePartsInventoryCheckList(queryRecord);
                    if (existRecords.size() > 0)
                    {
                        existRecord = existRecords.get(0);
                    }
                }
                
                if (StringUtils.isNull(existRecord))
                {
                    this.insertSparePartsInventoryCheck(record);
                    successNum++;
                    successMsg.append("<br/>" + successNum + "、备件盘点记录 " + record.getCheckName() + " 导入成功");
                }
                else if (isUpdateSupport)
                {
                    record.setId(existRecord.getId());
                    record.setUpdateBy(operName);
                    this.updateSparePartsInventoryCheck(record);
                    successNum++;
                    successMsg.append("<br/>" + successNum + "、备件盘点记录 " + record.getCheckName() + " 更新成功");
                }
                else
                {
                    failureNum++;
                    failureMsg.append("<br/>" + failureNum + "、备件盘点记录 " + record.getCheckName() + " 已存在");
                }
            }
            catch (Exception e)
            {
                failureNum++;
                String msg = "<br/>" + failureNum + "、备件盘点记录 " + record.getCheckName() + " 导入失败：";
                failureMsg.append(msg + e.getMessage());
            }
        }
        if (failureNum > 0)
        {
            failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据格式不正确，错误如下：");
            throw new ServiceException(failureMsg.toString());
        }
        else
        {
            successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
        }
        return successMsg.toString();
    }
}
